# vRO XML Package Parser

## Table of Contents

- [Overview](#overview)
- [Setup](#setup)
- [Usage](#usage)
- [Support These Projects](#support-these-projects)

## Overview
This project is an addendum to the vRealize Build Tools and Developer Tools. 

This project parses scriptable tasks out of Workflow XML, saves them as descrete files for editing and SCC, and imports edits in code back into XML for inclusion in vRO Package updates.
## Setup

Right now, the library is not hosted on **PyPi** so you will need to do a local
install on your system if you plan to use it in other scrips you use.

First, clone this repo to your local system. After you clone the repo, make sure
to run the `setup.py` file, so you can install any dependencies you may need. To
run the `setup.py` file, run the following command in your terminal.

```console
pip install -e .
```

This will install all the dependencies listed in the `setup.py` file. Once done
you can use the library wherever you want.

## Usage

Here is a simple example of using the `vroParse` library to grab the index
files for specific quarter.

```python
```

## Other Projects

**vRealize Build Tools:**
[vRealize Build Tools](https://flings.vmware.com/vrealize-build-tools) is a Vmware Fling that provides tools to development and release teams implementing solutions based on vRealize Automation (vRA) and vRealize Orchestrator (vRO).

**vRealize Developer Tools:**
[vRealize Developer Tools](https://github.com/vmware/vrealize-developer-tools) is a Visual Studio Code Extension available on GitHub that provides code intelligence features and enables a more developer-friendly experience when creating vRealize content.
